@@ -12,8 +12,9 @@ HOST = '192.168.8.104:80'  # 生产
 # HOST = '127.0.0.1:5001'
 
 
-# PRE = 'http://'
-PRE = 'https://s'
+PRE = 'http://'
+# PRE = 'https://s'
+# PRE = 'https://tests'
 
 # -----------------------------------------------------------------------------------------
 # 主要获取innercode信息
